==> wims_4.02.orig.tar.gz: wims-4.02.orig/wims/public_html/scripts/js/editor/names_it.js <==
var names= new Array();

names["lang_name"]="Italiano";
names["insert_selection"]="inserire la selezione";
names["not_available"]="La versione "+names["lang_name"]+" non  ancora disponibile.";
names["contextual_help"]="Help contestuale (con autocompletamento)";
names["contextual_help_desc"]="Iserisci una <em>backslash</em> (<code>\\</code>) seguita da una lettera minuscola per attivare l'autocompletamento. La lisa dei comandi sar filtrata di conseguenza.";

/** HTML entities ***/
names["Italics"]="Corsivo";
names["Bold"]="Grassetto";

names["Link"]="Link";
names["Link_Text"]="Testo del link";
names["Enter_Link_URL"]="Inserire l'URL del link";

names["Image"]="Immagine";
names["image_alt"]="descrizione dell'immagine";
names["Enter_img_URL"]="Inserire il nome del file immagine:";

names["Heading"]="Intestazione liv. 1";
names["Unordered_List"]="Elenco non numerato";
names["Ordered_List"]="Elenco numerato";
names["List_item"]="List Item";
names["wims_link"]="Internal link in the document";
names["Enter_link_name"]="Inserire il nome del nuovo blocco:";
names["wims_fold"]="Fold in the document";
names["Enter_fold_name"]="Inserire il nome del nuovo blocco:";
names["wims_href"]="Link a un file";
names["Enter_href_name"]="Inserire il nome del file:";
names["Enter_href_name2"]="Inserire il testo del link:";
/** WIMS 'before' instructions **/
names["title"]="Titolo";
names["User_guide"]="Modo d'uso";
names["author"]="Autore";
names["range"]="Intervallo";
names["email"]="Email";

/** WIMS 'during' instructions  **/ 
names["statement"]="Enunciato";
names["hint"]="Suggerimento";
names["help"]="Help";


/** WIMS 'After' instructions **/
names["answer"]="Risposta";
names["feedback"]="Feedback";
names["condition"]="Condizione";
names["solution"]="Soluzione";

==> wims_4.04~dfsg2.orig.tar.gz: wims-4.04~dfsg2/wims/public_html/scripts/js/editor/names_it.js <==
var names= new Array();

names["lang_name"]="Italiano";
names["insert_selection"]="inserire la selezione";
names["not_available"]="La versione "+names["lang_name"]+" non  ancora disponibile.";
names["contextual_help"]="Help contestuale (con autocompletamento)";
names["contextual_help_desc"]="Iserisci una <em>backslash</em> (<code>\\</code>) seguita da una lettera minuscola per attivare l'autocompletamento. La lisa dei comandi sar filtrata di conseguenza.";

/** HTML entities ***/
names["Italics"]="Corsivo";
names["Bold"]="Grassetto";

names["Link"]="Link";
names["Link_Text"]="Testo del link";
names["Enter_Link_URL"]="Inserire l'URL del link";

names["Image"]="Immagine";
names["image_alt"]="descrizione dell'immagine";
names["Enter_img_URL"]="Inserire il nome del file immagine:";

names["Heading"]="Intestazione liv. 1";
names["Unordered_List"]="Elenco non numerato";
names["Ordered_List"]="Elenco numerato";
names["List_item"]="List Item";
names["wims_link"]="Internal link in the document";
names["Enter_link_name"]="Inserire il nome del nuovo blocco:";
names["wims_fold"]="Fold in the document";
names["Enter_fold_name"]="Inserire il nome del nuovo blocco:";
names["wims_href"]="Link a un file inserito nel documento";
names["Enter_href_name"]="Inserire il nome del file:";
names["Enter_href_name2"]="Inserire il testo del link:";

/** WIMS 'before' instructions **/
names["title"]="Titolo";
names["User_guide"]="Modo d'uso";
names["author"]="Autore";
names["range"]="Intervallo";
names["email"]="Email";

/** WIMS 'during' instructions  **/ 
names["statement"]="Enunciato";
names["hint"]="Suggerimento";
names["help"]="Help";


/** WIMS 'After' instructions **/
names["answer"]="Risposta";
names["feedback"]="Feedback";
names["condition"]="Condizione";
names["solution"]="Soluzione";
